@@ -25,18 +25,19 @@ import gtk
 import gobject
 import pango
 
-# Try to import gtkspell
-gtkspell = None
 try:
     import gtkspell
 except ImportError:
-    pass
+    gtkspell = None
 
 from rednotebook.gui import t2t_highlight
 from rednotebook import undo
 from rednotebook.util import filesystem
 
 
+DEFAULT_FONT = gtk.settings_get_default().get_property('gtk-font-name')
+
+
 class Editor(object):
     def __init__(self, day_text_view, undo_redo_manager):
         self.day_text_view = day_text_view
@@ -66,8 +67,7 @@ class Editor(object):
         # So we forbid that behaviour, by setting a minimum width
         self.day_text_view.set_size_request(1, -1)
 
-        font_name = gtk.settings_get_default().get_property('gtk-font-name')
-        self.font = pango.FontDescription(font_name)
+        self.font = pango.FontDescription(DEFAULT_FONT)
         self.default_size = self.font.get_size() / pango.SCALE
         logging.debug('Default font: %s' % self.font.to_string())
         logging.debug('Default size: %s' % self.default_size)
@@ -199,11 +199,9 @@ class Editor(object):
         text = self.get_selected_text() or ' '
         self.replace_selection_and_highlight(markup, text, markup)
 
-    def set_font_size(self, size):
-        if size <= 0:
-            size = self.default_size
-        self.font.set_size(size * pango.SCALE)
-        self.day_text_view.modify_font(self.font)
+    def set_font(self, font_name):
+        font = pango.FontDescription(font_name)
+        self.day_text_view.modify_font(font)
 
     def hide(self):
         self.day_text_view.hide()
@@ -266,10 +264,6 @@ class Editor(object):
                 self._spell_checker.detach()
                 self._spell_checker = None
 
-    def is_spell_check_enabled(self):
-        """Returns True if spell check is enabled"""
-        return self._spell_checker is not None
-
     #===========================================================
 
     #def on_drop(self, widget, drag_context, x, y, timestamp):
