@@ -17,14 +17,14 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 # -----------------------------------------------------------------------
 
-import sys
-import os
 import datetime
 import logging
+import os
+import sys
 
-import gtk
 import gobject
-
+import gtk
+import pango
 
 from rednotebook.gui.menu import MainMenuBar
 from rednotebook.gui.options import OptionsManager
@@ -32,7 +32,6 @@ from rednotebook.gui import customwidgets
 from rednotebook.gui.customwidgets import CustomComboBoxEntry, CustomListView
 from rednotebook.util import filesystem
 from rednotebook import templates
-from rednotebook.util import markup
 from rednotebook.util import dates
 from rednotebook import undo
 from rednotebook.gui import categories
@@ -40,6 +39,7 @@ from rednotebook.gui.exports import ExportAssistant
 from rednotebook.gui import browser
 from rednotebook.gui import search
 from rednotebook.gui.editor import Editor
+from rednotebook.gui import editor
 from rednotebook.gui.clouds import Cloud
 from rednotebook.gui import insert_menu
 from rednotebook.gui import format_menu
@@ -153,8 +153,7 @@ class MainWindow(object):
 
         self.load_values_from_config()
 
-        if not self.journal.start_minimized:
-            self.main_frame.show()
+        self.main_frame.show()
 
         self.options_manager = OptionsManager(self)
         self.export_assistant = ExportAssistant(self.journal)
@@ -223,6 +222,8 @@ class MainWindow(object):
         #   self.day_text_field.day_text_view.add_accelerator(signal, self.accel_group,
         #                   ord(key), gtk.gdk.CONTROL_MASK, gtk.ACCEL_VISIBLE)
 
+        self.main_frame.connect('key-press-event', self._on_key_press_event)
+
         shortcuts = [
             (self.back_one_day_button, 'clicked', '<Ctrl>Page_Up'),
             (self.today_button, 'clicked', '<Alt>Home'),
@@ -231,12 +232,16 @@ class MainWindow(object):
             #(self.builder.get_object('redo_menuitem'), 'activate', '<Ctrl>y'),
             #(self.builder.get_object('options_menuitem'), 'activate', '<Ctrl><Alt>p'),
         ]
-
         for button, signal, shortcut in shortcuts:
             (keyval, mod) = gtk.accelerator_parse(shortcut)
             button.add_accelerator(signal, self.accel_group,
                                    keyval, mod, gtk.ACCEL_VISIBLE)
 
+    def _on_key_press_event(self, widget, event):
+        # Exit fullscreen mode with ESC.
+        if event.keyval == gtk.keysyms.Escape and self.is_fullscreen:
+            self.toggle_fullscreen()
+
 
     # TRAY-ICON / CLOSE --------------------------------------------------------
 
@@ -312,13 +317,13 @@ class MainWindow(object):
 
         if self.journal.config.read('closeToTray', 0):
             self.hide()
-
-            # the default handler is _not_ to be called,
-            # and therefore the window will not be destroyed.
-            return True
         else:
             self.journal.exit()
 
+        # We never call the default handler. Otherwise, the window would be
+        # destroyed, but we might no actually want to exit.
+        return True
+
     def on_quit_activate(self, widget):
         '''
         User selected quit from the menu -> exit unconditionally
@@ -443,11 +448,9 @@ class MainWindow(object):
     def toggle_fullscreen(self):
         if self.is_fullscreen:
             self.main_frame.unfullscreen()
-            self.menubar.show()
             self.is_fullscreen = False
         else:
             self.main_frame.fullscreen()
-            self.menubar.hide()
             self.is_fullscreen = True
 
     def on_back_one_day_button_clicked(self, widget):
@@ -512,6 +515,8 @@ class MainWindow(object):
         dialog.hide()
 
         if answer == gtk.RESPONSE_OK:
+            # Even if the user aborts the Save-As dialog, we don't want to exit.
+            self.journal.is_allowed_to_exit = False
             # Let the user select a new directory. Nothing has been saved yet.
             self.menubar_manager.on_save_as_menu_item_activate(None)
         elif answer == gtk.RESPONSE_CANCEL and exit_imminent:
@@ -573,19 +578,11 @@ class MainWindow(object):
         # By default do not show tags pane.
         self.edit_pane.set_position(config.read('rightDividerPosition', main_frame_width))
 
-        # A font size of -1 applies the standard font size
-        main_font_size = config.read('mainFontSize', -1)
+        self.set_font(config.read('mainFont', editor.DEFAULT_FONT))
 
-        self.set_font_size(main_font_size)
-
-    def set_font_size(self, main_font_size):
-        # -1 sets the default font size on Linux
-        # -1 does not work on windows, 0 means invisible
-        if sys.platform == 'win32' and main_font_size <= 0:
-            main_font_size = 10
-
-        self.day_text_field.set_font_size(main_font_size)
-        self.html_editor.set_font_size(main_font_size)
+    def set_font(self, font_name):
+        self.day_text_field.set_font(font_name)
+        self.html_editor.set_font_size(pango.FontDescription(font_name).get_size() / pango.SCALE)
 
     def setup_template_menu(self):
         def update_menu(button):
@@ -659,7 +656,7 @@ class Preview(browser.HtmlView):
 
         # Show new day
         self.day = new_day
-        html = markup.convert(self.day.text, 'xhtml', self.journal.dirs.data_dir)
+        html = self.journal.convert(self.day.text, 'xhtml')
         self.load_html(html)
 
         if self.day.last_preview_pos is not None:
@@ -876,9 +873,6 @@ class Calendar(object):
             self.calendar.unmark_day(day_number)
 
     def set_month(self, month):
-        #month_days = dates.get_number_of_days(month.year_number, month.month_number)
-        #for day_number in range(1, month_days + 1):
-        #   self.set_day_edited(day_number, False)
         self.calendar.clear_marks()
         for day_number, day in month.days.items():
             self.set_day_edited(day_number, not day.empty)
@@ -892,7 +886,7 @@ class Calendar(object):
         '''
         cal_year, cal_month, cal_day = self.calendar.get_date()
         cal_month += 1
-        if not day_number in range(1, dates.get_number_of_days(cal_year, cal_month) + 1):
+        if day_number not in range(1, dates.get_number_of_days(cal_year, cal_month) + 1):
             logging.debug('Non-existent date in calendar: %s.%s.%s' %
                         (day_number, cal_month, cal_year))
             return False
