@@ -30,15 +30,15 @@ except ImportError:
     from rednotebook.external import argparse
 
 
-version = '1.7.1'
+version = '1.9.0'
 author = 'Jendrik Seipp'
-authorMail = 'jendrikseipp@web.de'
+author_mail = 'jendrikseipp@web.de'
 url = 'http://rednotebook.sourceforge.net'
 answers_url = 'https://answers.launchpad.net/rednotebook'
 translation_url = 'https://translations.launchpad.net/rednotebook/'
 bug_url = 'https://bugs.launchpad.net/rednotebook/+filebug'
 
-developers = ['Jendrik Seipp <jendrikseipp@web.de>',
+developers = ['%(author)s <%(author_mail)s>' % locals(),
               '',
               'Contributors:',
               'Alistair Marshall <thatscottishengineer@gmail.com>']
@@ -86,15 +86,13 @@ def get_commandline_parser():
         formatter_class=argparse.RawTextHelpFormatter)
     parser.add_argument('--version', action='version',
                         version='RedNotebook %s' % version)
-    parser.add_argument('-m', '--minimized', dest='minimized', action='store_true',
-                        help='start mimimized to system tray')
+    parser.add_argument('--date', dest='start_date',
+                        help='load specified date (format YYYY-MM-DD only)')
     parser.add_argument('journal', nargs='?', help=journal_path_help)
     return parser
 
 
 tags = _('Tags')
-work = _('Work')
-free_time = _('Free time')
 todo = _('Todo')
 done = _('Done')
 rtm = _('Remember the milk')
@@ -161,29 +159,24 @@ completeWelcomeText = '''\
 
 welcome_day = {'text': completeWelcomeText}
 
-multiple_entries_text = '''\
-=== Multiple Entries ===
-You can add multiple entries to one day in two ways:
-- Use two different journals (one named "%(work)s", the other "%(free_time)s")
-- Separate your two entries by different titles (===%(work)s===, ===%(free_time)s===)
-- Use a horizontal separator line (20 “=”s)
+multiple_entries_text = _('''\
+=== Multiple entries ===
+You can add multiple entries to a single day by \
+using different journals (one named "Work", the other "Family"), \
+separating your entries with different titles (=== Work ===, === Family ===) \
+and using horizontal separator lines (20 “=”s).''')
 
-
-''' % globals()
-
-multiple_entries_example = '''\
-====================
-
-=== %(work)s ===
+multiple_entries_example = _('''\
+=== Work ===
 Here goes the first entry. It is about #work.
 
 ====================
 
-=== %(free_time)s ===
-Here comes the entry about the #fun_stuff.
-''' % globals()
+=== Family ===
+Here comes the entry about my #family.''')
 
-multiple_entries_day = {'text': multiple_entries_text + multiple_entries_example}
+multiple_entries_day = {
+    'text': multiple_entries_text + '\n\n' + 20 * '=' + '\n\n' + multiple_entries_example}
 
 example_content = [welcome_day, multiple_entries_day]
 
@@ -222,7 +215,7 @@ instead of "-" you can create a **numbered list**.
 == Hashtags ==
 %(tags_par)s
 
-== Advanced Tagging ==
+== Advanced tagging ==
 Until #hashtags were introduced, you could only tag a day with the tag panel on
 the right side, that is now hidden by default. Drag the slider to the left to
 see it.
@@ -255,7 +248,12 @@ from inside RedNotebook by opening the menu next to the "Template" button.
 On the left you find the search box. Double-clicking on a day in the search
 results lets you jump to it.
 
+You can search for text or dates (e.g. 2014, 2014-01, 2014-01-19).
+
 == Clouds ==[clouds]
+The 42 most frequently used words will appear in the word cloud on the left. Its
+contents are only refreshed after a program restart and when the journal is saved.
+
 If a word appears in the cloud that you don't want to see there, just right-click
 and select to hide it.
 Alternatively you can open the Preferences dialog and add the word to the cloud blacklist.
@@ -339,7 +337,7 @@ Obviously you have to be connected to the internet to use that feature. Be sure
 data regularly if you plan to save your content remotely. There are always more pitfalls when
 an internet connection is involved.
 
-=== Dual Boot ===
+=== Dual boot ===
 Using RedNotebook from multiple operating systems on the same computer is
 also possible. Save your Journal with "Journal->Save As" in a directory
 all systems can access. Then on the other systems you can open the
@@ -413,7 +411,7 @@ open the .tex file with Texniccenter and select "Build Output" from the
 "Output" menu. The program will then create the beautifully looking PDF in the
 same directory.
 
-== Keyboard Shortcuts ==
+== Keyboard shortcuts ==
 ||   Action          |   Shortcut             |
 | Preview (On/Off)   | <Ctrl> + P             |
 | Find               | <Ctrl> + F             |
@@ -469,7 +467,7 @@ So --%(rtm)s-- becomes struck through and **%(dishes)s** becomes bold.
 Once you've finished an item, you could also change its tag name from
 "%(todo)s" to "%(done)s".
 
-=== Week Numbers ===
+=== Week numbers ===
 If you'd like to see the week numbers in the calendar, you can set the
 value of weekNumbers to 1 in the configuration file. This file
 normally resides at $HOME/.rednotebook/configuration.cfg
@@ -556,9 +554,8 @@ Formatting commands inside two pairs of "" are not interpreted (""**not bold**""
 Comments can be inserted after percent signs (**%%**). They will not be shown in the
 preview and the exports. The %% has to be the first character on the line.
 
-=== List of all Entries ===
-To get a list of all entries, just search for " " (the space character).
-This character is most likely included in all entries. You can sort the
+=== List of all entries ===
+To get a list of your entries search for "-". You can sort the
 resulting list chronologically by pressing the "Date" button.
 
 == Command line options ==
@@ -566,7 +563,7 @@ resulting list chronologically by pressing the "Date" button.
 %(commandline_help)s
 ```
 
-== Data Format ==
+== Data format ==
 In this paragraph I will explain shortly what the RedNotebook files
 consist of. Firstly it is important to understand that the content
 is saved in a directory with many files, not just one file.
