@@ -75,6 +75,7 @@ except locale.Error, err:
 
 
 from rednotebook.util import utils
+from rednotebook.util import markup
 from rednotebook import info
 from rednotebook import configuration
 from rednotebook import data
@@ -116,7 +117,6 @@ def setup_logging(log_file):
     # add the handler to the root logger
     root_logger.addHandler(console)
 
-    logging.debug('Debug message')
     logging.info('Writing log to file "%s"' % log_file)
 
 
@@ -178,12 +178,6 @@ class Journal:
 
         logging.info('Running in portable mode: %s' % self.dirs.portable)
 
-        # Allow starting minimized to tray
-        # When we start minimized we have to set the tray icon visible
-        self.start_minimized = args.minimized
-        if self.start_minimized:
-            self.config['closeToTray'] = 1
-
         self.month = None
         self.date = None
         self.months = {}
@@ -201,7 +195,7 @@ class Journal:
 
         utils.set_environment_variables(self.config)
 
-        self.actual_date = datetime.date.today()
+        self.actual_date = self.get_start_date()
 
         # Let components check if the MainWindow has been created
         self.frame = None
@@ -261,12 +255,22 @@ class Journal:
                       'Execute "rednotebook -h" for instructions' % path_arg)
         sys.exit(1)
 
+    def get_start_date(self):
+        '''
+        Retrieve the date from optional args or otherwise return 'today'
+        '''
+        if not args.start_date:
+            return datetime.date.today()
+
+        try:
+            return dates.get_date_from_date_string(args.start_date)
+        except ValueError:
+            logging.error('Invalid date: %s (required format: YYYY-MM-DD).' % args.start_date)
+            sys.exit(2)
 
     def exit(self):
         self.frame.add_values_to_config()
 
-        self.config['running'] = 0
-
         # Make it possible to stop the program from exiting
         # e.g. if the journal could not be saved
         self.is_allowed_to_exit = True
@@ -279,22 +283,29 @@ class Journal:
             logging.shutdown()
             gtk.main_quit()
 
+    def convert(self, text, target, headers=None, options=None):
+        options = options or {}
+        options['font'] = self.config.read('previewFont', 'Ubuntu, sans-serif')
+        return markup.convert(text, target, self.dirs.data_dir, headers=headers, options=options)
 
     def save_to_disk(self, exit_imminent=False, changing_journal=False, saveas=False):
         self.save_old_day()
 
         try:
             filesystem.make_directory(self.dirs.data_dir)
-        except OSError:
+        except (OSError, IOError):
             self.frame.show_save_error_dialog(exit_imminent)
             return True
 
         something_saved = storage.save_months_to_disk(self.months,
-            self.dirs.data_dir, self.frame, exit_imminent, changing_journal, saveas)
+            self.dirs.data_dir, self.frame, exit_imminent, saveas)
 
         if something_saved:
             self.show_message(_('The content has been saved to %s') % self.dirs.data_dir, error=False)
             logging.info('The content has been saved to %r' % self.dirs.data_dir)
+        elif something_saved is None:
+            # Don't display this as an error, because we already show a dialog.
+            self.show_message(_('The journal could not be saved'), error=False)
         else:
             self.show_message(_('Nothing to save'), error=False)
 
@@ -346,11 +357,7 @@ class Journal:
         self.title = filesystem.get_journal_title(data_dir)
 
         # Set frame title
-        if self.title == 'data':
-            frame_title = 'RedNotebook'
-        else:
-            frame_title = 'RedNotebook - ' + self.title
-        self.frame.main_frame.set_title(frame_title)
+        self.set_frame_title()
 
         # Save the folder for next start
         if not self.dirs.portable:
@@ -359,6 +366,12 @@ class Journal:
             rel_data_dir = filesystem.get_relative_path(self.dirs.app_dir, data_dir)
             self.config['dataDir'] = rel_data_dir
 
+    def set_frame_title(self):
+        parts = ['RedNotebook']
+        if self.title != 'data':
+            parts.append(self.title)
+        parts.append(dates.format_date('%x', self.date))
+        self.frame.main_frame.set_title(' - '.join(parts))
 
     def get_month(self, date):
         '''
@@ -369,7 +382,7 @@ class Journal:
         year_and_month = dates.get_year_and_month_from_date(date)
 
         # Selected month has not been loaded or created yet
-        if not year_and_month in self.months:
+        if year_and_month not in self.months:
             self.months[year_and_month] = Month(date.year, date.month)
 
         return self.months[year_and_month]
@@ -398,6 +411,8 @@ class Journal:
 
         self.frame.set_date(self.month, self.date, self.day)
 
+        self.set_frame_title()
+
 
     def merge_days(self, days):
         '''
@@ -444,8 +459,14 @@ class Journal:
     def show_message(self, msg, title=None, error=False):
         if error and not title:
             title = _('Error')
-        msg_type = gtk.MESSAGE_ERROR if error else gtk.MESSAGE_INFO
+        if error:
+            msg_type = gtk.MESSAGE_ERROR
+            log_level = logging.ERROR
+        else:
+            msg_type = gtk.MESSAGE_INFO
+            log_level = logging.INFO
         self.frame.show_message(title, msg, msg_type)
+        logging.log(log_level, '%s. %s' % (title, msg))
 
 
     @property
